#ifndef __PARPRE_VEC_PACKAGE 
#define __PARPRE_VEC_PACKAGE
#include "vec.h"
#include "sys.h"

typedef enum 
{PETSC_NOT_SET_VALUES, PETSC_INSERT_VALUES, 
 PETSC_ADD_VALUES, PETSC_MAX_VALUES} ParPreInsertMode;

#endif
